# caen-libs
Official Python binding for CAEN VMELib, CAEN Comm, CAEN PLU and CAEN HV Wrapper libraries.

## Install
You need to install the latest version of the libraries from [the CAEN website](https://www.caen.it/subfamilies/software-libraries/).

Then, install this module and have fun:

    pip install caen-libs

## Examples
Few examples may be found on the [`examples`](https://github.com/caenspa/py-caen-libs/tree/main/examples) folder of the project repository.

## Copyright notice
Copyright &copy; 2024 CAEN SpA

The caen-libs module is free software; you can redistribute it and/or
modify it under the terms of the **GNU Lesser General Public
License** as published by the Free Software Foundation; either
version 3 of the License, or (at your option) any later version.

The caen-libs module is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along
with the caen-libs module; if not, see https://www.gnu.org/licenses/.

The license applies to the caen-libs module source as a whole, though
individual source files can have a different license which is required to be
compatible with the GNU Lesser General Public Library, version 3.

## References
Requirements and documentation can be found at https://www.caen.it/subfamilies/software-libraries/.

## Support
For technical support, go to https://www.caen.it/mycaen/support/ (login and
MyCAEN+ account required).
